@@ -3,15 +3,16 @@ Main interface for batch service.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.batch import (
+    from mypy_boto3_batch import (
         BatchClient,
         Client,
         DescribeComputeEnvironmentsPaginator,
         DescribeJobDefinitionsPaginator,
         DescribeJobQueuesPaginator,
         ListJobsPaginator,
-        )
+    )
 
     session = boto3.Session()
 
@@ -22,6 +23,7 @@ Usage::
     describe_job_definitions_paginator: DescribeJobDefinitionsPaginator = client.get_paginator("describe_job_definitions")
     describe_job_queues_paginator: DescribeJobQueuesPaginator = client.get_paginator("describe_job_queues")
     list_jobs_paginator: ListJobsPaginator = client.get_paginator("list_jobs")
+    ```
 """
 from mypy_boto3_batch.client import BatchClient, BatchClient as Client
 from mypy_boto3_batch.paginator import (
