@@ -3,13 +3,15 @@ Main interface for batch service client
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.batch import BatchClient
+    from mypy_boto3_batch import BatchClient
 
     session = boto3.Session()
 
     client: BatchClient = boto3.client("batch")
     session_client: BatchClient = session.client("batch")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
