@@ -3,8 +3,11 @@ Main interface for batch service client paginators.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.batch import (
+
+    from mypy_boto3_batch import BatchClient
+    from mypy_boto3_batch import (
         DescribeComputeEnvironmentsPaginator,
         DescribeJobDefinitionsPaginator,
         DescribeJobQueuesPaginator,
@@ -17,6 +20,7 @@ Usage::
     describe_job_definitions_paginator: DescribeJobDefinitionsPaginator = client.get_paginator("describe_job_definitions")
     describe_job_queues_paginator: DescribeJobQueuesPaginator = client.get_paginator("describe_job_queues")
     list_jobs_paginator: ListJobsPaginator = client.get_paginator("list_jobs")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
